# pylint: disable=missing-class-docstring, invalid-name
"""
ESI models for providers

These models have been generated from stubs of compatibility date 2026-03-20.
Make sure to update them as compatibility date changed
"""

from datetime import datetime
from typing import Literal, TypedDict


class CharactersCharacterIdAssetsGetItem(TypedDict):
    is_blueprint_copy: bool | None
    is_singleton: bool
    item_id: int
    location_flag: Literal[
        "AssetSafety",
        "AutoFit",
        "BoosterBay",
        "CapsuleerDeliveries",
        "Cargo",
        "CorporationGoalDeliveries",
        "CorpseBay",
        "Deliveries",
        "DroneBay",
        "ExpeditionHold",
        "FighterBay",
        "FighterTube0",
        "FighterTube1",
        "FighterTube2",
        "FighterTube3",
        "FighterTube4",
        "FleetHangar",
        "FrigateEscapeBay",
        "Hangar",
        "HangarAll",
        "HiSlot0",
        "HiSlot1",
        "HiSlot2",
        "HiSlot3",
        "HiSlot4",
        "HiSlot5",
        "HiSlot6",
        "HiSlot7",
        "HiddenModifiers",
        "Implant",
        "InfrastructureHangar",
        "LoSlot0",
        "LoSlot1",
        "LoSlot2",
        "LoSlot3",
        "LoSlot4",
        "LoSlot5",
        "LoSlot6",
        "LoSlot7",
        "Locked",
        "MedSlot0",
        "MedSlot1",
        "MedSlot2",
        "MedSlot3",
        "MedSlot4",
        "MedSlot5",
        "MedSlot6",
        "MedSlot7",
        "MobileDepotHold",
        "MoonMaterialBay",
        "QuafeBay",
        "RigSlot0",
        "RigSlot1",
        "RigSlot2",
        "RigSlot3",
        "RigSlot4",
        "RigSlot5",
        "RigSlot6",
        "RigSlot7",
        "ShipHangar",
        "Skill",
        "SpecializedAmmoHold",
        "SpecializedAsteroidHold",
        "SpecializedCommandCenterHold",
        "SpecializedFuelBay",
        "SpecializedGasHold",
        "SpecializedIceHold",
        "SpecializedIndustrialShipHold",
        "SpecializedLargeShipHold",
        "SpecializedMaterialBay",
        "SpecializedMediumShipHold",
        "SpecializedMineralHold",
        "SpecializedOreHold",
        "SpecializedPlanetaryCommoditiesHold",
        "SpecializedSalvageHold",
        "SpecializedShipHold",
        "SpecializedSmallShipHold",
        "StructureDeedBay",
        "SubSystemBay",
        "SubSystemSlot0",
        "SubSystemSlot1",
        "SubSystemSlot2",
        "SubSystemSlot3",
        "SubSystemSlot4",
        "SubSystemSlot5",
        "SubSystemSlot6",
        "SubSystemSlot7",
        "Unlocked",
        "Wardrobe",
    ]
    location_id: int
    location_type: Literal["station", "solar_system", "item", "other"]
    quantity: int
    type_id: int


class CharactersCharacterIdAssetsLocationsPostItem_Position(TypedDict):
    """Manually generated model"""

    x: int
    y: int
    z: int


class CharactersCharacterIdAssetsLocationsPostItem(TypedDict):
    """Manually generated model"""

    item_id: int
    position: CharactersCharacterIdAssetsLocationsPostItem_Position


class CharactersCharacterIdNotificationsGetItem(TypedDict):
    is_read: bool | None
    notification_id: int
    sender_id: int
    sender_type: Literal["character", "corporation", "alliance", "faction", "other"]
    text: str | None
    timestamp: datetime
    type: Literal[
        "AcceptedAlly",
        "AcceptedSurrender",
        "AgentRetiredTrigravian",
        "AllAnchoringMsg",
        "AllMaintenanceBillMsg",
        "AllStrucInvulnerableMsg",
        "AllStructVulnerableMsg",
        "AllWarCorpJoinedAllianceMsg",
        "AllWarDeclaredMsg",
        "AllWarInvalidatedMsg",
        "AllWarRetractedMsg",
        "AllWarSurrenderMsg",
        "AllianceCapitalChanged",
        "AllianceWarDeclaredV2",
        "AllyContractCancelled",
        "AllyJoinedWarAggressorMsg",
        "AllyJoinedWarAllyMsg",
        "AllyJoinedWarDefenderMsg",
        "BattlePunishFriendlyFire",
        "BillOutOfMoneyMsg",
        "BillPaidCorpAllMsg",
        "BountyClaimMsg",
        "BountyESSShared",
        "BountyESSTaken",
        "BountyPlacedAlliance",
        "BountyPlacedChar",
        "BountyPlacedCorp",
        "BountyYourBountyClaimed",
        "BuddyConnectContactAdd",
        "CharAppAcceptMsg",
        "CharAppRejectMsg",
        "CharAppWithdrawMsg",
        "CharLeftCorpMsg",
        "CharMedalMsg",
        "CharTerminationMsg",
        "CloneActivationMsg",
        "CloneActivationMsg2",
        "CloneMovedMsg",
        "CloneRevokedMsg1",
        "CloneRevokedMsg2",
        "CombatOperationFinished",
        "ContactAdd",
        "ContactEdit",
        "ContainerPasswordMsg",
        "ContractRegionChangedToPochven",
        "CorpAllBillMsg",
        "CorpAppAcceptMsg",
        "CorpAppInvitedMsg",
        "CorpAppNewMsg",
        "CorpAppRejectCustomMsg",
        "CorpAppRejectMsg",
        "CorpBecameWarEligible",
        "CorpDividendMsg",
        "CorpFriendlyFireDisableTimerCompleted",
        "CorpFriendlyFireDisableTimerStarted",
        "CorpFriendlyFireEnableTimerCompleted",
        "CorpFriendlyFireEnableTimerStarted",
        "CorpKicked",
        "CorpLiquidationMsg",
        "CorpNewCEOMsg",
        "CorpNewsMsg",
        "CorpNoLongerWarEligible",
        "CorpOfficeExpirationMsg",
        "CorpStructLostMsg",
        "CorpTaxChangeMsg",
        "CorpVoteCEORevokedMsg",
        "CorpVoteMsg",
        "CorpWarDeclaredMsg",
        "CorpWarDeclaredV2",
        "CorpWarFightingLegalMsg",
        "CorpWarInvalidatedMsg",
        "CorpWarRetractedMsg",
        "CorpWarSurrenderMsg",
        "CorporationGoalClosed",
        "CorporationGoalCompleted",
        "CorporationGoalCreated",
        "CorporationGoalExpired",
        "CorporationGoalLimitReached",
        "CorporationGoalNameChange",
        "CorporationLeft",
        "CustomsMsg",
        "DailyItemRewardAutoClaimed",
        "DeclareWar",
        "DistrictAttacked",
        "DustAppAcceptedMsg",
        "ESSMainBankLink",
        "EntosisCaptureStarted",
        "ExpertSystemExpired",
        "ExpertSystemExpiryImminent",
        "FWAllianceKickMsg",
        "FWAllianceWarningMsg",
        "FWCharKickMsg",
        "FWCharRankGainMsg",
        "FWCharRankLossMsg",
        "FWCharWarningMsg",
        "FWCorpJoinMsg",
        "FWCorpKickMsg",
        "FWCorpLeaveMsg",
        "FWCorpWarningMsg",
        "FacWarCorpJoinRequestMsg",
        "FacWarCorpJoinWithdrawMsg",
        "FacWarCorpLeaveRequestMsg",
        "FacWarCorpLeaveWithdrawMsg",
        "FacWarDirectEnlistmentRevoked",
        "FacWarLPDisqualifiedEvent",
        "FacWarLPDisqualifiedKill",
        "FacWarLPPayoutEvent",
        "FacWarLPPayoutKill",
        "FreelanceProjectClosed",
        "FreelanceProjectCompleted",
        "FreelanceProjectCreated",
        "FreelanceProjectExpired",
        "FreelanceProjectLimitReached",
        "FreelanceProjectParticipantKicked",
        "GameTimeAdded",
        "GameTimeReceived",
        "GameTimeSent",
        "GiftReceived",
        "IHubDestroyedByBillFailure",
        "IncursionCompletedMsg",
        "IndustryOperationFinished",
        "IndustryTeamAuctionLost",
        "IndustryTeamAuctionWon",
        "InfrastructureHubBillAboutToExpire",
        "InsuranceExpirationMsg",
        "InsuranceFirstShipMsg",
        "InsuranceInvalidatedMsg",
        "InsuranceIssuedMsg",
        "InsurancePayoutMsg",
        "InvasionCompletedMsg",
        "InvasionSystemLogin",
        "InvasionSystemStart",
        "JumpCloneDeletedMsg1",
        "JumpCloneDeletedMsg2",
        "KillReportFinalBlow",
        "KillReportVictim",
        "KillRightAvailable",
        "KillRightAvailableOpen",
        "KillRightEarned",
        "KillRightUnavailable",
        "KillRightUnavailableOpen",
        "KillRightUsed",
        "LPAutoRedeemed",
        "LocateCharMsg",
        "MadeWarMutual",
        "MercOfferRetractedMsg",
        "MercOfferedNegotiationMsg",
        "MercenaryDenAttacked",
        "MercenaryDenNewMTO",
        "MercenaryDenReinforced",
        "MissionCanceledTriglavian",
        "MissionOfferExpirationMsg",
        "MissionTimeoutMsg",
        "MoonminingAutomaticFracture",
        "MoonminingExtractionCancelled",
        "MoonminingExtractionFinished",
        "MoonminingExtractionStarted",
        "MoonminingLaserFired",
        "MutualWarExpired",
        "MutualWarInviteAccepted",
        "MutualWarInviteRejected",
        "MutualWarInviteSent",
        "NPCStandingsGained",
        "NPCStandingsLost",
        "OfferToAllyRetracted",
        "OfferedSurrender",
        "OfferedToAlly",
        "OfficeLeaseCanceledInsufficientStandings",
        "OldLscMessages",
        "OperationFinished",
        "OrbitalAttacked",
        "OrbitalReinforced",
        "OwnershipTransferred",
        "RaffleCreated",
        "RaffleExpired",
        "RaffleFinished",
        "ReimbursementMsg",
        "ResearchMissionAvailableMsg",
        "RetractsWar",
        "SPAutoRedeemed",
        "SeasonalChallengeCompleted",
        "SkinSequencingCompleted",
        "SkyhookDeployed",
        "SkyhookDestroyed",
        "SkyhookLostShields",
        "SkyhookOnline",
        "SkyhookUnderAttack",
        "SovAllClaimAquiredMsg",
        "SovAllClaimLostMsg",
        "SovCommandNodeEventStarted",
        "SovCorpBillLateMsg",
        "SovCorpClaimFailMsg",
        "SovDisruptorMsg",
        "SovStationEnteredFreeport",
        "SovStructureDestroyed",
        "SovStructureReinforced",
        "SovStructureSelfDestructCancel",
        "SovStructureSelfDestructFinished",
        "SovStructureSelfDestructRequested",
        "SovereigntyIHDamageMsg",
        "SovereigntySBUDamageMsg",
        "SovereigntyTCUDamageMsg",
        "StationAggressionMsg1",
        "StationAggressionMsg2",
        "StationConquerMsg",
        "StationServiceDisabled",
        "StationServiceEnabled",
        "StationStateChangeMsg",
        "StoryLineMissionAvailableMsg",
        "StructureAnchoring",
        "StructureCourierContractChanged",
        "StructureDestroyed",
        "StructureFuelAlert",
        "StructureImpendingAbandonmentAssetsAtRisk",
        "StructureItemsDelivered",
        "StructureItemsMovedToSafety",
        "StructureLostArmor",
        "StructureLostShields",
        "StructureLowReagentsAlert",
        "StructureNoReagentsAlert",
        "StructureOnline",
        "StructurePaintPurchased",
        "StructureServicesOffline",
        "StructureUnanchoring",
        "StructureUnderAttack",
        "StructureWentHighPower",
        "StructureWentLowPower",
        "StructuresJobsCancelled",
        "StructuresJobsPaused",
        "StructuresReinforcementChanged",
        "TowerAlertMsg",
        "TowerResourceAlertMsg",
        "TransactionReversalMsg",
        "TutorialMsg",
        "WarAdopted ",
        "WarAllyInherited",
        "WarAllyOfferDeclinedMsg",
        "WarConcordInvalidates",
        "WarDeclared",
        "WarEndedHqSecurityDrop",
        "WarHQRemovedFromSpace",
        "WarInherited",
        "WarInvalid",
        "WarRetracted",
        "WarRetractedByConcord",
        "WarSurrenderDeclinedMsg",
        "WarSurrenderOfferMsg",
    ]
