"""Esi related exceptions"""

from dataclasses import dataclass
from typing import Any


class MissingTokenError(Exception):
    """Raised when the token for this user isn't found"""


@dataclass
class NotModified(Exception):
    """Raised when a non modified exception was thrown by the provider. Resource didn't change"""

    operation_name: str
    args: list | None = None
    body: Any | None = None
