# Generated by Django 5.2.12 on 2026-03-20 22:06

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("dens", "0004_discordwebhook"),
        ("eve_sde", "0018_blueprintactivity_blueprintactivityproduct_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mercenaryden",
            name="location",
            field=models.OneToOneField(
                help_text="Location of the den",
                on_delete=django.db.models.deletion.CASCADE,
                to="eve_sde.planet",
            ),
        ),
    ]
