# Generated by Django 4.2.21 on 2025-08-04 07:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("dens", "0003_alter_mercenaryden_location"),
    ]

    operations = [
        migrations.CreateModel(
            name="DiscordWebhook",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "webhook_url",
                    models.CharField(
                        help_text="Webhook URL", max_length=255, unique=True
                    ),
                ),
                ("is_enabled", models.BooleanField(default=True)),
                (
                    "name",
                    models.CharField(
                        help_text="Text to recognize the webhook",
                        max_length=30,
                        unique=True,
                    ),
                ),
            ],
        ),
    ]
