"""Mercenary dens plugin app for Alliance Auth."""

# pylint: disable = invalid-name

from datetime import date

from .app_settings import DENS_CUSTOM_COMPATIBILITY_DATE

__version__ = "2.0.0"
app_name = "aa-dens"
repo_url = "https://gitlab.com/r0kym/aa-dens"
if DENS_CUSTOM_COMPATIBILITY_DATE:
    compatibility_date = DENS_CUSTOM_COMPATIBILITY_DATE
else:
    compatibility_date = date(2026, 3, 20)
