{% load evelinks %}

<a href="{{ row.location.solar_system.name|dotlan_solar_system_url }}">
    {{ row.location.solar_system.name }}
</a>
&nbsp;
<span>{{ row.location.solar_system.security_status|floatformat }}</span>
