"""App settings."""

from datetime import date

from django.conf import settings

from dens.vendor.app_utils.app_settings import clean_setting

DENS_ADMIN_NOTIFICATIONS_ENABLED = clean_setting(
    "DENS_ADMIN_NOTIFICATIONS_ENABLED", True
)

DENS_FORWARD_TIMER_TO_TIMERBOARD = clean_setting(
    "DENS_FORWARD_TIMER_TO_TIMERBOARD", True
)

DENS_USE_ETAGS = clean_setting(
    "DENS_USE_ETAGS",
    True,
)


DENS_CUSTOM_COMPATIBILITY_DATE: date | str | None = getattr(
    settings, "DENS_CUSTOM_COMPATIBILITY_DATE", None
)
