# Generated by Django 4.2.29 on 2026-04-12 17:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("eveonline", "0017_alliance_and_corp_names_are_not_unique"),
        ("dens", "0001_initialize"),
    ]

    operations = [
        migrations.CreateModel(
            name="MercenaryDenUnderAttackNotification",
            fields=[
                ("id", models.BigIntegerField(primary_key=True, serialize=False)),
                (
                    "attack_time",
                    models.DateTimeField(
                        help_text="Timestamp when the den was attacked", null=True
                    ),
                ),
                ("raw_text", models.TextField(blank=True)),
                (
                    "attacked_by",
                    models.ForeignKey(
                        help_text="Character that attacked the Mercenary Den",
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="eveonline.evecharacter",
                    ),
                ),
                (
                    "den",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="dens.mercenaryden",
                    ),
                ),
            ],
        ),
    ]
